@@ -49,34 +49,34 @@ class pykakeGui:
 
     # WINDOWS
     def mainWindow(self):  # Window to select between modes
-	 program = hildon.Program.get_instance()
-	 win = hildon.StackableWindow()
-	 win.set_title("%s v.%s" % (APP_TITLE, APP_VERSION))
-	 win.connect('destroy', self.destroy)
-	 win.set_border_width(0)
-	 menu = self.mainMenu()
-	 win.set_app_menu(menu)
-	 vbox = gtk.VBox(False, 0)
-	 win.add(vbox)
-	 label = gtk.Label("Select mode:")
-	 label.modify_font(fontLabel)
-	 vbox.pack_start(label, False, True, 0)
-	 hbox = gtk.HBox(False, 10)
-	 vbox.pack_start(hbox, True, True, 0)
-	 self.butt1 = gtk.Button("Basic")
-	 self.butt1.child.modify_font(fontButt)
-	 self.butt1.connect('clicked', self.singleShot, None)
-	 hbox.pack_start(self.butt1, True, True, 0)
-	 self.butt2 = gtk.Button("Bulb")
-	 self.butt2.child.modify_font(fontButt)
-	 self.butt2.connect('clicked', self.bulbMode, None)
-	 hbox.pack_start(self.butt2, True, True, 0)
-	 self.butt3 = gtk.Button("Viewer")
-	 self.butt3.child.modify_font(fontButt)
-	 self.butt3.connect('clicked', self.viewerMode, None)
-	 vbox.pack_start(self.butt3, True, True, 0)
-	 win.show_all()
-	 self.buttControl()
+	program = hildon.Program.get_instance()
+	win = hildon.StackableWindow()
+	win.set_title("%s v.%s" % (APP_TITLE, APP_VERSION))
+	win.connect('destroy', self.destroy)
+	win.set_border_width(0)
+	menu = self.mainMenu()
+	win.set_app_menu(menu)
+	vbox = gtk.VBox(False, 0)
+	win.add(vbox)
+	label = gtk.Label("Select mode:")
+	label.modify_font(fontLabel)
+	vbox.pack_start(label, False, True, 0)
+	hbox = gtk.HBox(False, 10)
+	vbox.pack_start(hbox, True, True, 0)
+	self.butt1 = gtk.Button("Basic")
+	self.butt1.child.modify_font(fontButt)
+	self.butt1.connect('clicked', self.singleShot, None)
+	hbox.pack_start(self.butt1, True, True, 0)
+	self.butt2 = gtk.Button("Bulb")
+	self.butt2.child.modify_font(fontButt)
+	self.butt2.connect('clicked', self.bulbMode, None)
+	hbox.pack_start(self.butt2, True, True, 0)
+	self.butt3 = gtk.Button("Viewer")
+	self.butt3.child.modify_font(fontButt)
+	self.butt3.connect('clicked', self.viewerMode, None)
+	vbox.pack_start(self.butt3, True, True, 0)
+	win.show_all()
+	self.buttControl()
 
     def singleShot(self, widget, data): # Mode to just take photos
 	win = hildon.StackableWindow()
@@ -254,7 +254,7 @@ class pykakeGui:
 	vbox.pack_start(hbox1, True, True, 0)
 
 	# Selecting timer beeb interwall
-	label2 = gtk.Label("Select time interwall for beebs:")
+	label2 = gtk.Label("Select time interval for beebs:")
 	t30sec = hildon.GtkRadioButton(gtk.HILDON_SIZE_AUTO, None)
 	t30sec.set_label("30 Sec")
 	t30sec.set_mode(False)
@@ -358,20 +358,22 @@ License along with this program.   If not, see
 		self.buttBulb.child.modify_font(fontButt)
 		self.timer()
 		bulbStatus = True
-		if CURRENT_REMOTETYPE == "Olympus_RM-1":
+		if CURRENT_REMOTETYPE == "Olympus_RM-1" or CURRENT_REMOTETYPE == "Pentax_RC-F":
 		    data = "bulbon"
 	    else:
 		self.buttBulb.set_label("Bulb On")
 		self.buttBulb.child.modify_font(fontButt)
 		self.timerStop()
 		bulbStatus = False
-		if CURRENT_REMOTETYPE == "Olympus_RM-1":
+		if CURRENT_REMOTETYPE == "Olympus_RM-1" or CURRENT_REMOTETYPE == "Pentax_RC-F":
 		    data = "bulboff"
 
 	if CURRENT_REMOTETYPE == "Olympus_RM-1":
 	    digitalCamera().olympus(data)
 	elif CURRENT_REMOTETYPE == "CANON-RC1/RC5":
 	    digitalCamera().canon()
+	elif CURRENT_REMOTETYPE == "Pentax_RC-F":
+	    digitalCamera().pentax(data)
 	else:
 	    digitalCamera().oneButtonRemotes(CURRENT_REMOTETYPE)
 
@@ -520,10 +522,24 @@ class digitalCamera: # This is class where commands from GUI are translated read
 	    cmd = "S"
 	self.remote(cmd)
 
-    def oneButtonRemotes(self, remote):
-	if remote == "Pentax_RC-F":
+    def pentax(self, data):
+	if data == "bulbon":
+	    """ Sending start command in bulb mode """
+#	    print "Pentax - Bulb on."
+	    self.bulbPatchPentax("start")
+
+	elif data == "bulboff":
+	    """ Sending stop command in bulb mode """
+#	    print "Pentax - Bulb off"
+	    self.bulbPatchPentax("stop")
+
+	else:
+	    """ Sending normal shutter command. """
 	    cmd = "Capture"
-	elif remote == "NikonDSLR":
+	    self.remote(cmd)
+
+    def oneButtonRemotes(self, remote):
+	if remote == "NikonDSLR":
 	    cmd = "shutter"
 	else:
 	    print "There is no camera selected"
@@ -540,6 +556,23 @@ class digitalCamera: # This is class where commands from GUI are translated read
 	shoot.wait()
 	# Need some kind of failback system + some info (more than what camera it self gives, example some kind of sound played after send.
 
+    def bulbPatchPentax(self, state):
+	remote = CURRENT_REMOTETYPE
+	code = "Capture"
+	if state == "start":
+	    """ Start send the signal """
+	    directive = "send_start"
+	elif state == "stop":
+	    """ Stop send the signal """
+	    directive = "send_stop"
+	else:
+	    """ Something failed in getting state of bulb, only sending command once. """
+	    directive = "send_once"
+	arg = ["/usr/bin/irsend", directive, remote, code]
+	shoot = subprocess.Popen (arg, stdin = subprocess.PIPE)
+	shoot.stdin.close()
+	shoot.wait()
+
 class miscFuncs: # Some miscaleous functions (For the sake of simplicity
     # Lircd controller
     def controlLircd(self, cmd): # For starting and shutting down lirc in the start-up and close of program (or drive any other command you want
